pub struct OptimizeResult {
pub plan: LogicalPlan,
pub applied_rules: Vec<String>,
}Expand description
The result of running the optimizer over a logical plan.
Fields
plan: LogicalPlanThe (possibly rewritten) logical plan.
applied_rules: Vec<String>Names of the rules that fired and changed the plan, in application order.
Implementations