pub fn decode_window_execution_spec(
encoded: &str,
) -> Result<WindowExecutionSpec, PlanError>Expand description
Decode a lossless window specification, accepting legacy compact fragments for backward compatibility.
pub fn decode_window_execution_spec(
encoded: &str,
) -> Result<WindowExecutionSpec, PlanError>Decode a lossless window specification, accepting legacy compact fragments for backward compatibility.