Logical and physical plan types for Krishiv.
R1 bootstrap keeps these types deliberately small. Later R1 work will bridge them to DataFusion logical and physical plans without exposing DataFusion as the long-term public Krishiv API.
Re-exports
pub use expression::AggregateFunction as ExprAggregateFunction;pub use expression::BinaryOperator as ExprBinaryOperator;pub use expression::EXPRESSION_FORMAT_VERSION;pub use expression::Expr;pub use expression::ExprDataType;pub use expression::ExprField;pub use expression::IntervalUnit;pub use expression::NullOrdering;pub use expression::ScalarValue;pub use expression::SortDirection;pub use expression::TimeUnit;pub use task_fragment::TASK_FRAGMENT_VERSION;pub use task_fragment::TypedTaskFragment;pub use task_fragment::encode_typed_task_fragment;pub use task_fragment::execution_kind_from_fragment;pub use task_fragment::task_body_for_profile;pub use task_fragment::validate_job_fragments;
Modules
- cep
- Complex event processing (CEP) sequential pattern matcher (R16 S2).
- expression
- Versioned, engine-owned public expression and scalar type contract.
- governance
- Minimal authentication and access-control interfaces for Krishiv.
- optimizer
- Query optimizer traits and infrastructure for Krishiv.
- task_
fragment - Typed task fragments with explicit execution kind (unified batch/streaming).
- udf
- User-defined function (UDF) extension framework for Krishiv.
- window
- Streaming window plan configuration and fragment encoding (unified execution).
Structs
- Logical
Plan - Krishiv logical plan wrapper.
- Physical
Plan - Krishiv physical plan wrapper.
- Plan
Diff - Summary of structural differences between two physical plans.
- Plan
Node - A small bootstrap plan node used by both logical and physical plans.
- Plan
Schema - Output schema for a plan node.
- Schema
Field - One field in a plan schema.
Enums
- Execution
Kind - Whether a plan represents bounded batch work, unbounded streaming, or IVM.
- Field
Type - Data type for a plan schema field.
- Join
Type - Join variant used in
NodeOp::Join. - NodeOp
- Typed operator classification for a plan node.
- Partitioning
- Partitioning strategy for a plan node’s output.
- Plan
Error - Errors returned by plan encoding, decoding, and validation operations.
Constants
- MAX_
PLAN_ NODES - Maximum number of nodes allowed in a single plan.
Functions
- diff_
plans - Compute the structural diff between two physical plans.
- lower_
to_ physical - Validate and lower a logical plan into a physical plan.