pub fn encode_stream_fragment(
spec: &WindowExecutionSpec,
) -> Result<String, PlanError>Expand description
Encode a window spec as an executor plan fragment description.
Single-aggregate specs use the compact text format for backward
compatibility. Multi-aggregate specs delegate to the lossless JSON
format because the compact format’s : field delimiter conflicts with
agg parameter syntax (agg=sum:col=amount).